@@ -23,6 +23,8 @@ function parseBarcode(elb, node) {
     res.reservedTicket.ticketedSeat.seatSection = stripLeadingZeros(elb.segment1.coachNumber);
     res.reservedTicket.ticketedSeat.seatNumber = stripLeadingZeros(elb.segment1.seatNumber);
     res.reservedTicket.ticketedSeat.seatingType = elb.segment1.classOfTransport;
+    res.reservedTicket.validFrom = elb.validFromDate();
+    //res.reservedTicket.validUntil = elb.validUntilDate(); TODO this is set bus looks implausible?
     return res;
 }
 
